
%%%%%%%% Plain TeX file, formatted for journal Integers  %%%%%%%%%%%%%


\magnification=\magstephalf
\voffset=30pt
\hoffset=10pt
\parskip=10pt
\parindent=0pt
\hsize=6.25 true in
\vsize=9.0 true in
\font\smallit=cmti9
\font\smalltt=cmtt9
\font\smallrm=cmr8

\headline={\ifnum\pageno<2 \hfil \else \smalltt INTEGERS: \smallrm
ELECTRONIC JOURNAL OF COMBINATORIAL NUMBER THEORY \smalltt 2 (2002), \#A01
\hfil \folio \fi}

\footline={\hfil}


%%%%%%%%%%%%%%%%%  Definitions  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\Oh{{\it O\/}}    % big Oh notation
\def\E{{\cal E}}
\def\O{{\cal O}}
\def\mod{{\rm ~mod~}}


\centerline{\bf
ON THE PROBLEM OF UNIQUENESS FOR THE }
\centerline{\bf MAXIMUM STIRLING NUMBER(S) OF THE SECOND KIND}
\vskip 30pt
\centerline{\bf E. Rodney Canfield}
\centerline{\smallit Department of Computer Science, University of Georgia}
\centerline{\smallit Athens, GA 30602 USA }
\centerline{\tt erc@cs.uga.edu}
\vskip 10pt
\centerline{\bf Carl Pomerance}
\centerline{\smallit Fundamental Mathematics Department,
           Bell Laboratories/Lucent Technologies}
\centerline{\smallit Murray Hill, NJ 07974-0636}
\centerline{\tt carlp@research.bell-labs.com}
\vskip 40pt
\centerline{\smallit Received:  9/10/01, 
Accepted:  1/15/02, Published: 1/16/02 }
\vskip 30pt

\baselineskip=5pt
\centerline{\bf Abstract}

Say that an integer $n$ is {\it exceptional} if the
maximum Stirling number of the second kind
$S(n,k)$ occurs for two (of necessity consecutive) 
values of $k$.
We prove that the number of exceptional
integers less than or equal to $x$ is
$\Oh(x^{3/5+\epsilon})$, for any $\epsilon>0$.

\baselineskip=15pt
\parindent=15pt
\vskip 30pt

%%%%%%%%%%%%%%%%%  References  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\Bach{1}
\def\Canfield{2}
\def\Comtet{3}
\def\Dobson{4}
\def\Erdos{5}
\def\Harper{6}
\def\Hayman{7}
\def\Harborth{8}
\def\Huxley{9}
\def\KanoldA{10}
\def\KanoldB{11}
\def\KanoldC{12}
\def\Lieb{13}
\def\Menon{14}
\def\Moser{15}
\def\Mullin{16}
\def\Odlyzko{17}
\def\RD{18}
\def\Wegner{19}
\def\Wilf{20}

%% section 1
\line{\bf 1. Introduction \hfil}
\vskip 10pt
\noindent
Let $S(n,k)$ be the Stirling number of the second kind,
that is, the number
of partitions of an $n$-set into $k$ non empty, pairwise disjoint
blocks.  (Detailed definitions appear in the next section.)
Using the initial value
$S(0,k)=\delta_{0\,k}$ and the recursion
$$ S(n+1,k) ~~=~~ kS(n,k) ~+~ S(n,k-1) \eqno(1) $$
one may show by induction on $n$ that 
$$ S(n,k)^2 ~~\ge~~ (1+{3 \over k}) \, S(n,k-1) \, S(n,k+1),
~~~ 1 \le k \le n. \eqno(2) $$
It follows that the ratio $S(n,k+1)/S(n,k)$ is strictly decreasing,
and so there is either a unique maximum Stirling number
$$ S(n,k) ~~<~~ S(n,K_n), {\rm ~~for~all~} k \not= K_n$$
or else there are two consecutive peaks
$$  S(n,k) ~~<~~ S(n,K_n) ~~=~~ S(n,K_n+1), {\rm ~~for~all~} k \not\in 
\{K_n,K_n+1\}.  $$
Define the {\it exceptional set} $E$ to be those $n$ for which
the second alternative holds.  Based on computation through
$n=10^6$ reported in the final section, it is possible
that $E=\{2\}$.  Let $E(x)$
denote the associated counting function 
$$ E(x) ~~=~~ \#\{n:n \le x {\rm ~and~} n\in E\}. $$
The purpose of this paper is to prove

\vskip 8pt

\noindent{\bf Theorem 1.} For any $\epsilon>0$,
$$ E(x) ~~=~~ \Oh(x^{3/5+\epsilon}). $$

\vskip 8pt

\noindent Our proof of this theorem
depends on the fact that, when $n \in E$, the quantity
$e^r$, where $r$ is the unique real solution of the
equation $re^r=n$, must be unusually close to an integer
plus $1/2$.  (See equation (5) in Section 3.)   Starting
from (5) and using only
elementary arguments, we will
prove in Section 4 a result slightly weaker
than Theorem 1, namely with the exponent
$3/5$ replaced by $2/3$.  Then, in Section 5, we will
prove Theorem 1 by invoking recent work of Huxley [\Huxley] on
counting integer points near curves.  In Section
6, we give a heuristic argument for why $E$ should be a
finite set.  Finally, in Section 7, we report on the computation
and supporting lemma that proves $E\cap(1,10^6]=\emptyset$.

\vskip 30pt

%% section 2
\line{\bf 2. Definitions and Background \hfil}
\vskip 10pt
\noindent
A {\it partition} of the set $[n]=\{1,2,\dots,n\}$ is a collection
of non empty pairwise disjoint subsets of $[n]$, called {\it blocks}, whose
union equals $[n]$.  For example, $\{\{1,4\},\{2,3,5,7\},\{6\}\}$
is a partition of $[7]$ into 3 blocks.  The Stirling number of the
second kind, $S(n,k)$, is the number of partitions of $[n]$ into
$k$ blocks.  Every partition of $[n+1]$ into $k$ blocks
can be obtained either by adjoining $\{n+1\}$ as a singleton block to 
an existing partition of $[n]$ into $k-1$ blocks, or by adding the 
element $n+1$ to one of the blocks of an existing partition of $[n]$ 
into $k$ blocks.  This construction proves the recursion (1).
Here is a table of the 
first few rows of the Stirling numbers of the second kind:

$$\vbox{
\halign{\hfill#\quad\hfill&&\quad\hfill#\cr
$n\backslash k$&1&2&3&4&5\cr
1&1\cr
2&1&1\cr
3&1&3&1\cr
4&1&7&6&1\cr
5&1&15&25&10&1\cr
}}$$

As explained in the Introduction, for each $n \ge 1$
there is a unique integer $K_n$ satisfying
$$ S(n,1) ~<~ \cdots ~<~ S(n,K_n) ~\ge~ S(n,K_n+1).$$
In words, $K_n$ is the location of the maximum Stirling number of the 
second kind, with the proviso that should there
be two consecutive maxima, $K_n$ is the
location of the ``leftmore.''  The {\it exceptional set}
$E$ consists of $n$ such that $S(n,K_n)=S(n,K_n+1)$, and
$E(x)$ is the number of $n \le x$ belonging to $E$.

There is a vast literature on the Stirling numbers to which many
people have contributed, and many properties have been
independently rediscovered.
Harper's [\Harper] contributions are particulary noteworthy.
He shows that the polynomials
$\sum_kS(n,k)x^k$ have only real roots, a property called
{\it total positivity}, which is stronger than log concavity.
He articulates the unique-or-double peak property
(3), and proves the asymptotic relation
$K_n \sim n/\log n$, (His formula contains a superflous
factor $e$ which was later corrected.)  The
asymptotic formula was obtained by others, for example [\RD].
Citing Harper's work, Lieb [\Lieb]
derives an inequality similar to (2),
based on the general {\it Newton Inequality} for
coefficients of polynomials whose roots are all real and
negative.
The very nice fact that $K_{n+1}$ equals either $K_n$ or $K_n+1$
appears in [\Dobson] and [\Mullin].
Using (1) and (2), it can be shown that a necessary condition
for $n \in E$ is $K_{n+1}=K_n+1$.  Thus,
the growth condition $K_{n+1}-K_n \in \{0,1\}$ plus
the asymptotic relation $K_n \sim n/\log n$
together imply that $E(x)=\Oh(x/\log x)$, as first pointed out
by Wegner [\Wegner].   The latter paper of Wegner
makes the explicit conjecture that $E=\{2\}$.
Prior to the general adoption of more powerful analytic tools, in a series
of papers [\Bach, \Harborth, \KanoldA, \KanoldB, \KanoldC]
the authors Bach,
Harborth, and Kanold employ clever elementary arguments to prove many 
interesting, sharp inequalities about $K_n$.

The fact that the signless Stirling numbers of the first kind do
indeed have always a unique maximum is due to Erd\H{o}s [\Erdos].

The status of the ``duplicate maximum'' problem has
been misstated in the literature more 
than once.  A source of misunderstanding might be the one line abstract,
perpetuated in the
Mathematical Reviews, of [\Dobson] which states,
``For fixed $n$, Stirling numbers of the second
kind, $S(n,r)$, have a single maximum.''   Reading the
paper, one sees clearly that the intended meaning is precisely
(3); but certainly the statement can be easily misconstrued when read
in isolation.

Canfield [\Canfield] and
Menon [\Menon] independently
showed that $K_n$ is always equal to $\lfloor \kappa(n) 
\rfloor$ or $\lceil \kappa(n) \rceil$, where $\kappa(n)$ is a certain
transcendentally defined function.  It will follow from what we say
in Section 3 that for sufficiently large $n$ a simpler definition of 
$\kappa(n)$ also satisfies
the latter theorem, namely $\kappa(n)=e^r-1$, where $ re^r= n.$
Throughout the paper, we shall always use $r(x)$ for the implicitly defined 
function 
$$ r(x)e^{r(x)} ~~=~~ x, $$
and the symbol $r$, with no argument, denotes
$r(n)$.  For $ 1 \le n \le 1200$ there is no exception to the relation
$$ K_n ~~\in~~ \{ \lfloor e^r-1 \rfloor, \lceil e^r-1 \rceil \}, \eqno(4) $$
although it has been proven true only for $n$ sufficiently large.

\vskip 30pt

%% section 3.      
\line{\bf 3. Asymptotics of the Stirling Numbers $S(n,k)$ \hfil}
\vskip 10pt
\noindent
We will neglect polylog factors in our estimates, and so it is 
convenient to define
$$ F_1(x) ~~=~~ \Oh_*(F_2(x)) $$
to mean that for a sufficiently large constant $C$ we have
$$ |F_1(x)| ~~\le~~ C (\log x)^C F_2(x), ~~~ {\rm for~} x \ge C. $$
This given, we may state the lemma that will be of central
importance.

\noindent{\bf Lemma 1.} For all sufficiently large $n \in E$ we have
$$ e^r ~~=~~ \lfloor e^r \rfloor ~+~ {1 \over 2} ~+~ {1/2 \over 1+r}
$$
where as usual $re^r=n$.

\noindent {\bf Proof.}  The exponential generating function in the letter
$n$ for $S(n,k)$ is [\Comtet]
$$ \sum_{n=k}^{\infty} S(n,k) {x^n \over n!} ~~=~~ {(e^x-1)^k \over 
k!}. $$
The Cauchy integral formula thus asserts
$$ {S(n,k) \over n!}  ~~=~~ {1 \over 2\pi ik!}
\oint_{|z|=R}{(e^z-1)^k \over z^{n+1}}dz, $$
for any $R>0$.  If we take the radius $R$ of the
circle of integration to be the
quantity $r$, and restrict attention to integers $k$ which satisfy the relations
$$ e^r-1 ~~=~~ k+\theta, ~~~~~ \theta = \Oh(1), $$
while making estimates such as those found in
[\Moser],  we arrive at
$$
S(n,k) ~~=~~ {(e^r-1)^k \over k!} {n! \over r^n} \bigl(2\pi kB\bigr)^{-1/2} 
          \Bigl(1 ~-~ {6r^2\theta^2+6r\theta+1 \over 12re^r} \Bigr)
$$
where 
$$B ~~=~~ B(r) ~~=~~ {re^{2r}-(r^2+r)e^r\over(e^r-1)^2}$$ 
depends on $r$ only.

This is very similar to the formula (1) in [\Canfield], although
the latter was unnecessarily conservative in the error estimate.
Now, with $k$ and $\theta$ as above, we find
$$ {S(n,k+1) \over S(n,k)} ~~=~~ 1 ~+~ {(r+1)\theta-{1 \over 2}r - 1
\over e^r} ~+~ \Oh_*(n^{-2}).
$$
It is this equation which gives us the assertion (4), for
all $n$ large, mentioned
earlier, and by setting the right side equal to 1, we obtain the
lemma.
\smallskip

\noindent{\bf Remark.} The asymptotic formula for $S(n,k)$, and the
more detailed one appearing in the proof of Lemma 2 in Section 6, 
are obtained by using the circle method.  We do not include any
details about how to use this method, which is a very standard and
widely used technique for obtaining asymptotic estimates of the
coefficients of analytic functions.  The reader for whom this is a
new topic should study [\Wilf, Section 4.5] before moving on to 
other papers.  A very good account of the circle method particularly useful 
for asymptotic enumeration is [\Hayman].  The paper of Moser and Wyman 
[\Moser] contains a lot of useful information about the particular case of 
the Stirling numbers.  Another good source for this topic is [\Odlyzko].

\vskip 30pt

%% section 4.
\line{\bf 4. The Elementary Proof \hfil}
\vskip 10pt
\noindent
Our goal in this section is to prove that for any $\epsilon>0$
$$ E(x) ~~=~~ \Oh(x^{2/3+\epsilon}).  $$
Let $\epsilon>0$ be given.  It suffices to show that for all
sufficiently large $X$
$$ \Bigl| [X,X+X^{1/3-\epsilon}] ~\cap~ E\Bigr| ~~\le~~ 2.  \eqno(6) $$
If (6) fails, then we have infinitely many $n$ such that
$n,n+\ell_1,n+\ell_2 \in E$ with $0<\ell_1<\ell_2 \le n^{1/3-\epsilon}$.
For each such $n$, we have $r$ with $re^r=n$, and also $r_i$
with $r_ie^{r_i}=n+\ell_i$.  Note that 
$$ \log x ~-~ \log\log x ~~\le~~ r(x) ~~\le~~ \log x, $$
whence
$$ r_i ~~\sim~~ r. $$
Since $r(x)e^{r(x)}=x$, it follows that
$$ e^{r_i} ~~\sim~~ e^r. $$
By Taylor's theorem and the facts that
$${d\over dx}e^{r(x)}~=~{1\over r(x)+1},
~~~{d^2\over dx^2}e^{r(x)}~=~{-1\over(r(x)+1)^3e^{r(x)}},
~~~{d^3\over dx^3}e^{r(x)}~=~{r(x)+4\over(r(x)+1)^5e^{2r(x)}},
$$
we have
$$\eqalign{
 e^{r_i} ~~&=~~ e^r ~+~ {\ell_i \over r+1} 
{1\over r_i+1}\cr ~~&=~~ {1\over r+1} ~-~ {\ell_i\over(r+1)^3e^r} }
$$
Thus,
$$(\ell_1-\ell_2)e^r ~+~ \ell_2 e^{r_1} ~-~ \ell_1 e^{r_2}
~=~~ - {\ell_2\ell_1^2-\ell_1\ell_2^2 \over 2 (r+1)^3 e^r}
 ~+~ \Oh_*\Bigl( {\ell_2\ell_1^3+\ell_1\ell_2^3  \over n^2} \Bigr).  $$
Similarly,
$$ {\ell_1-\ell_2 \over 1+r  } ~+~
   {\ell_2        \over 1+r_1} ~-~
   {\ell_1        \over 1+r_2} ~~=~~ 
\Oh_*\Bigl( {\ell_2\ell_1^2+\ell_1\ell_2^2  \over n^2} \Bigr).
$$
Let us refer to the assertions of Lemma 1, namely,
$$ e^{r_i} ~~=~~ m_i ~+~ 1/2 ~+~ {1/2 \over r_i+1}$$
as equation $i$, with $0 \le i \le 2$, taking $r_0=r$.  If we form
$(\ell_1-\ell_2)$ times equation 0 plus $\ell_2$ times equation 1
minus $\ell_1$ times equation 2, and substitute the above 
expansions, we find           
$$ - {\ell_2\ell_1^2-\ell_1\ell_2^2 \over 2 (r+1)^3 e^r}
 ~+~  \Oh_*\Bigl( {\ell_2\ell_1^3+\ell_1\ell_2^3  \over n^2} \Bigr)
 ~~=~~  {\rm INTEGER} ~+~  
\Oh_*\Bigl( {\ell_2\ell_1^2+\ell_1\ell_2^2  \over n^2} \Bigr).
$$
In the previous equation, every term except the one labeled
``INTEGER'' goes to 0 as $n \rightarrow \infty$; thus, for
all sufficiently large $n$ that term itself must be 0.  Dividing
through by $\ell_1\ell_2$ and collecting big-oh's,
$$  {\ell_2-\ell_1 \over 2 (r+1)^3 e^r}
 ~~=~~  
\Oh_*\Bigl( {\ell_1^2+\ell_2^2  \over n^2} \Bigr).
$$
Since, however, $\ell_2-\ell_1 \ge 1$, this last equality is
impossible.  Our initial assumption that (6) does not hold
is contradicted, and the proof is complete.

\vskip 30pt

%% section 5
\line{\bf 5. The Proof of Theorem 1 \hfil}
\vskip 10pt
\noindent
The theorem due to Huxley which we shall apply,
[\Huxley, (1.7)], bounds the number
of integer pairs $(n,m)$ which satisfy $|m-f(n)|\le\delta$
for $n\in[X,2X]$.  We shall apply this result to the function
$$ f(x) ~~=~~ e^{r(x)} ~-~ 1/2 ~-~ {1/2 \over 1+r(x)},  $$
with $\delta = X^{\epsilon-1}$.  With these choices, by Lemma 1, for
$X$ sufficiently large, we
include all members of $E\cap[X,2X]$ in the count.

The hypotheses required of $f(x)$ are that there be numbers
$C \ge 1$, $\Delta < 1$ such that
$$ C \Delta ~~\le~~ 1 $$
$$
{\Delta \over C} ~~\le~~ |f''(x)| ~~\le~~ C \Delta, ~~~ x \in[X,2X] 
$$
and
$$
|f^{(3)}(x)| ~~\le~~ {C \Delta \over X}, ~~~ x \in[X,2X].
$$

The conclusion of Huxley's theorem is that the number of
integer pairs $(n,m)$ is no greater than an unspecified constant
times          
$$
 1 ~+~ {1 \over b} \sqrt{C\delta\over\Delta} ~+~ C^2\delta X 
(\log X - \log 2C)^{c_i} \delta^{d_i},
$$
where $b$ is the least positive integer such that for some $x \in 
[X,2X]$ we have $b f'(x)$ within distance $\delta$ of an integer,
and the exponents $(a_i,b_i,c_i,d_i)$ in the sum assume
the four values $({2\over5},1,{1\over10},0)$, 
$({1\over5},{4\over5},{1\over10},0)$,
$({2\over7},1,{1\over7},{1\over7})$, and 
$({1\over7},{6\over7},{1\over7},{1\over7})$.

If we take $\Delta=X^{-1}$, then the quantity $C$ satisfying the 
hypotheses of Huxley's Theorem may be taken as $\Oh(X^\epsilon)$, 
and we obtain the result that between $X$
and $2X$ there are $\Oh(X^{3/5+\epsilon})$ elements of
$E$.  This estimate suffices to prove the Theorem. (By being
a bit more careful, one may use Huxley's Theorem to show that
the number of members of $E$ up to $X$ is at most
$X^{3/5}(\log X)^{{\rm O}(1)}$.)

\vskip 30pt

%% section 6
\line{\bf 6. A Heuristic \hfil}
\vskip 10pt
\noindent
In this section we give a strengthening of Lemma 1 that leads to
a heuristic argument that the set $E$ is finite.  Note that already the
estimate of Lemma 1 heuristically supports the conclusion that
$E(x)=\Oh(x^\epsilon)$, and with more care,
$E(x)\le (\log x)^{{\rm O}(1)}$.
To push this heuristic further we need a more precise version of Lemma 1.

\noindent{\bf Lemma 2.} 
%Let $D_r$ denote
%$$
%\left({\textstyle{1\over2}}r^2
%+{\textstyle{3\over2}}r+1\right)
%\left({\textstyle{1\over2}}r+1\right)^2 
%+\left({\textstyle{1\over2}}r^2+{\textstyle{3\over8}}r
%-{\textstyle{5\over4}}\right)
%\left({\textstyle{1\over2}}r+1\right)(r+1)
%+\left({\textstyle{1\over8}}r^2-{\textstyle{47\over48}}r
%+{\textstyle{9\over16}}\right)(r+1)^2.
%$$
For $n\in E$ and $re^r=n$, we have
$$
e^r~~=~~\left\lfloor e^r\right\rfloor+{1\over2}+{1/2\over1+r}+{A_r\over e^r}
+\Oh_*\left(n^{-2}\right),
$$
where $A_r$ is a rational function in $r$ with rational coefficients.
\medskip

\noindent{\bf Proof.}  With the same meaning for $k,\theta,B$ as in the proof
of Lemma 1, it is possible to show that uniformly for $|\theta|=\Oh(1)$,
we have
$$
 S(n,k) ~~=~~ {(e^r-1)^k \over k!} \, {n! \over r^n} \,
                      (2\pi kB)^{-1/2} \,
\Bigl(1 ~-~ {F_1 \over e^r} ~+~ {F_2 \over e^{2r}} ~+~ \Oh\bigl(
{r^3 \over e^{3r}}\bigr)
\Bigr),
$$
where
$$\eqalign{
F_1(\theta) ~~&=~~ {1+6r\theta+6r^2\theta^2 \over 12r},\cr
F_2(\theta) ~~&=~~ {1 \over 288r^2} \, \Bigl(
r^4(-36-144\theta-144\theta^2+36\theta^4) \cr
&~~~~~
+~r^3(96+144\theta-288\theta^2-24\theta^3)~+~r^2(-144\theta-24\theta^2)
}$$

Returning to the proof, it follows from the above formula that
$$
{S(n,k+1)\over S(n,k)} ~~=~~ {e^r-1\over k+1}\Bigl({k\over k+1}\Bigr)^{1/2}
\Bigl({1-F_1(\theta-1)e^{-r}+F_2(\theta-1)e^{-2r}\over
1-F_1(\theta)e^{-r}+F_2(\theta)e^{-2r}}+\Oh_*\left(n^{-3}\right)\Bigr).
\eqno{(7)}
$$
Suppose now that $n\in E$, so that $S(n,k+1)/S(n,k)=1$.  Write
$$
\theta~~=~~u+{1\over2}+{1/2\over r+1},
$$
so that Lemma 1 implies that $u=\Oh_*(n^{-1})$.  
Hence, if $g(x,y)\in{\bf Q}[x,y]$, then 
$$
g(r,\theta)~~=~~g\Bigl(r,{1\over2}+{1/2\over r+1}\Bigr)+\Oh_*\left(n^{-1}\right).
$$
Thus,
$$
{e^r-1\over k+1} ~~=~~ {e^r-1\over e^r-\theta} ~~=~~
1+{\theta-1\over e^r}+{\theta^2-\theta\over e^{2r}}
+\Oh_*\left(n^{-3}\right)
~=~~1+{\theta-1\over e^r}+{a_r\over e^{2r}}
+\Oh_*\left(n^{-3}\right),
$$
where $a_r$ is a rational function of $r$ with rational coefficients.  Also
$$
\left({k\over k+1}\right)^{1/2}~~=~~1-{1/2\over e^r}+{1/8-\theta/2\over e^{2r}}
+\Oh_*\left(n^{-3}\right)
~=~~1-{1/2\over e^r}+{b_r\over e^{2r}}
+\Oh_*\left(n^{-3}\right),
$$
where again, $b_r$ is in ${\bf Q}(r)$.  And
$$\eqalign{
&{1-F_1(\theta-1)e^{-r}+F_2(\theta-1)e^{-2r}\over 
1-F_1(\theta)e^{-r}+F_2(\theta)e^{-2r}}~~= \cr
&\ 1-{F_1(\theta-1)-F_1(\theta)\over e^r}
+{F_2(\theta-1)-F_2(\theta)+(F_1(\theta-1)-F_1(\theta))F_1(\theta)\over e^{2r}}
+\Oh_*\left(n^{-3}\right)\cr
& =~~ 1+{1/2-r/2+r\theta\over e^r}+{c_r\over e^{2r}}+\Oh_*\left(n^{-3}\right),
}$$
where $c_r\in{\bf Q}(r)$.

Thus (7) and the above estimates imply that
$$
1~~=~~\Bigl(1+{\theta-1\over e^r}+{a_r\over e^{2r}}\Bigr)
\Bigl(1-{1/2\over e^r}+{b_r\over e^{2r}}\Bigr)
\Bigl(1+{1/2-r/2+r\theta\over e^r}+{c_r\over e^{2r}}\Bigr)
+\Oh_*\left(n^{-3}\right).
$$
Subtracting 1 from both sides and multiplying by $e^r$, we get
$$\eqalign{
(r+1)&\theta-{\textstyle{1\over2}}-{\textstyle{1\over2}}(r+1) \cr
&=~~-~e^{-r}\left(a_r+b_r+c_r-{\textstyle{1\over2}}(\theta-1)
+(\theta-{\textstyle{3\over2}})({\textstyle{1\over2}}
-{\textstyle{1\over2}}r+r\theta)\right) \cr
&=~~d_re^{-r}~+~\Oh_*\left(n^{-2}\right),}
$$
where $d_r\in{\bf Q}(r)$.  Thus, we have Lemma 2.
\medskip

We now give a heuristic argument, based on Lemma 2, that the set
$E$ is finite.  
%First note that the equation $re^r=n$ implies that
%for each positive integer $n$, the number $r$ is transcendental.
%For if it were algebraic, then $e^r=n/r$ would also be algebraic,
%thus contradicting the Gelfond--Schneider theorem.  
With $re^r=x$, let
$$
g(x)~~=~~e^r-{1\over2}-{1/2\over r+1}-{A_r\over e^r}
~=~~{x\over r}-{1\over2}-{1/2\over r+1}-{rA_r\over x}.
$$
The function $g(x)$ is smooth with
$$
g'(x)~\sim~{1\over\log x},\quad g''(x)~\sim~{-1\over x\log^2x},
\quad g^{(3)}(x)~\sim~{1\over x^2\log^2x}.
$$
There is no reason to believe that $g(n)$ has a prediliction to
be close to an integer over any other transcendental number.
But Lemma 2 implies that for $n\in E$, we have $\|g(n)\|=\Oh_*(n^{-2})$,
where $\|\ \|$ denotes the distance to the nearest integer.
Heuristically, the number of such integers $n$ is $\sum \Oh_*(n^{-2})=\Oh(1)$.  
(One might view the expression $\Oh_*(n^{-2})$ as an upper bound for 
the ``probability" that $n\in E$, and the sum of these probabilities
is $\Oh(1)$.)

\vskip 30pt

%% section 7
\line{\bf 7. Numerics \hfil}
\vskip 10pt
\noindent
To verify that $E\cap(1,10^6]=\emptyset$, we wrote a program to compute
$S(n,k) \mod 2^{31}-1$.  We computed all such residues for $2\le n\le 10^6$
and $2\le k\le \min\{87890,~n\}$, finding 33 pairs $(n,k)$ satisfying the
conditions:
$$\eqalign{
& 2 ~\le~ n ~\le~ 10^6 \cr
& 2 ~\le~ k ~<~ \min\{87890,~2n/\log(n),~n\} \cr
& S(n,k) = S(n,k+1) \mod 2^{31}-1.
          }$$
We may impose the stated bounds on $k$ for these reasons: (1)
by Lemma 3, stated and proven below, $K_n < 2n/\log(n)$ for
$n \ge 151$; (2) an independent computation of exact values of
$S(n,k)$, using {\tt maple}, had already shown $E\cap(1,1200]=\emptyset$;
(3) $S(10^6,87848)>S(10^6,87890)$.

The third of these facts was established by making rigorous numerical
estimates, with considerable help from {\tt maple}.  The basis for
these estimates is the pair of inequalities
$$ {k^n \over k!} \, \sum_{j=0}^\O {k \choose j}(-1)^j(1-j/k)^n
~\le~~ S(n,k) ~~\le~~
{k^n \over k!} \, \sum_{j=0}^\E {k \choose j}(-1)^j(1-j/k)^n
\eqno(8)$$
for any positive odd integer $\O$ and nonnegative even integer
$\E$.
These are the Bonferroni inequalities
([\Comtet], Section 4.7 ).
We used
$\O=5$ and $\E=4$ to prove
$$\eqalign{
\log S(10^6,87848) ~~&>~~ 10\,471\,198  \cr
\log S(10^6,87890) ~~&<~~ 10\,471\,197.992  \cr
          } $$
Later, by taking $\E=10$ and $\O=11$ we were able to show conclusively
that
$$ K_{10^6} ~~=~~ 87846. $$
For anyone wishing to duplicate the computation, we provide these
checkpoints:
\item{$\bullet$} the first of the 33 pairs is $(n,k)=(124322,16581)$
\item{$\bullet$} the  last of the 33 pairs is $(n,k)=(965756,12911)$
\item{$\bullet$} $S(10^6,87890) = 1111899618 \mod 2^{31}-1$
\item{$\bullet$} $S(124322,16581) = 1636672468 \mod 2^{31}-1$
\item{$\bullet$} $S(965756,12911) =  897942184 \mod 2^{31}-1$


The program was modified to compute $S(n,k) \mod 2^{19}-1$, and
run a second time.  This second modulus was able to distinguish
31 of the pairs found in the first run;
for example,
$$
S(124322,16581) = 31493 \mod 2^{19}-1 ~~{\rm ~and~~~} S(124322,16582) =
504717 \mod 2^{19}-1.  $$
However, all four of the numbers $S(n,k)$ for $n=526314,k=51889,51890$
and $n=559358,k=52358,52359$ are $0 \mod 2^{19}-1$.  To distinguish
among these a further calculation was needed.  Note that the bounds
given in equation (8) are in fact equalities if $\E$, or as appropriate
$\O$, is equal to $k$.  For a prime $p>k$ this provides a way to compute
$S(n,k) \mod p$ directly, without computing any other Stirling numbers
in the process.  This identity shows, as shown in [\Wegner, (4.1)], that
$S(n,k) \equiv S(A,k)\mod p$ for prime $p>k$ and
$n\equiv A\not\equiv 0 \mod (p-1)$.  For the first few
primes $p$ larger than $k$, we have $0<A<k$, so for these primes $S(n,k)$
is congruent to 0.  The first prime larger than 51889 for which
$S(526314,51889)$ is not congruent to 0 is $p=52639$.  We have
$$ S(526314,51889) = 4890 \mod 52639, ~~~{\rm and~~~}
S(526314,51890) = 43718 \mod 52639.  $$
In a similar manner, the pair for $n=559358$ is distinguished by the
prime $p=55949$.  In this way, then, we prove there are no duplicate
maxima for $1<n\le 10^6$.

We now conclude with the above referenced lemma.


\noindent{\bf Lemma 3.} For all integers $n\ge151$ we have $K_n<2n/\log n$.

\noindent{\bf Proof.}  For any positive integer $k$ with $1\le k\le n$, we have
$$
{k^n\over k!}~-~{(k-1)^n\over(k-1)!}~~ \le~~ S(n,k)~~ \le~~ {k^n\over k!}.
\eqno(9)
$$
These inequalities are the case $\E=0$ and $\O=1$ of equation (8).
We include a from-scratch proof since it is not difficult.
Indeed, the number of assignments of the integers $1,\dots,n$ into $k$
labeled boxes with no box remaining empty is at most $k^n$, and each
set partition of $[n]$ corresponds to $k!$ such assignments.  Thus,
we have the upper bound in (9).  Further,
the number of assignments without the restriction that no box remain
empty is exactly $k^n$, and the number of assignments where box $i$
remains empty is exactly $(k-1)^n$.  Thus, the number of assignments
with no box remaining empty is at least $k^n-k(k-1)^n$.  From this,
the lower bound in (9) follows easily.

We now let $k=\lfloor n/\log n\rfloor$.  We will show that for $n\ge151$,
$$
{(2k)^n\over (2k)!}~~ <~~ {k^n\over k!}~-~{(k-1)^n\over(k-1)!}.
\eqno(10)
$$
Note that (9) and (10) show that $S(n,k)>S(n,2k)$, and so from (3),
we must have $K_n<2k$.  To see (10), let
$$
\alpha~~ =~~ {(2k)^n/(2k)!\over k^n/k!},~~~~ \beta~~ =~~ {(k-1)^n/(k-1)!\over
k^n/k!}.
$$
We will show that for $n\ge151$ we have $\alpha,\beta <1/2$, so that (10) follows
for these values of $n$.

We have
$$\eqalign{
\beta~~ =~~ k(1-1/k)^n~~ \le~~ ke^{-n/k}~~ &=~~ \lfloor n/\log n\rfloor
e^{-n/\lfloor n/\log n\rfloor}\cr
&\le~~ (n/\log n)e^{-\log n}~~ =~~ 1/\log n.}
$$
Thus, for $n\ge151$, we have $\beta\le1/\log151<1/5$.  The estimation for
$\alpha$ is a little more difficult.  We have
$$
\alpha^{-1}~~ =~~ {(2k)!\over k!}2^{-n}~~ =~~ k!{2k\choose k}2^{-n}.
$$
Using the inequalities $k!>(k/e)^k$, ${2k\choose k}\ge 2^{2k}/(2k)$, which
are both easy to see, we have
$$
\alpha^{-1}~~ >~~ k^{k-1}e^{-k}2^{2k-1-n},
$$
so that
$$\log(\alpha^{-1})~~ >~~ (k-1)(\log k+\log 4-1)-((n-1)\log2+1).
$$
An elementary check shows that this last expression exceeds 1 for all
integers $n\ge151$, so that $\alpha<1/e$ in this range.  This completes
the proof of (10) and the lemma.

\vskip 30pt

\line{\bf References \hfil}

\font\authorfont=cmss10
\def\bookfont{\it}
\def\articlefont{\rm}

% 1=number 2=author 3=title 4=publisher             start a book ref.
% 5=year
\def\book#1#2#3#4#5{\item{#1.}{\authorfont #2,
\bookfont #3}, {#4}, {#5}}

% 1=number 2=author 3=title                         start a paper ref. 
\def\reference#1#2#3{\item{#1.}{\authorfont #2,
\articlefont #3,}}

% 1=journal 2=volume 3=year 4=pages (use --)        if in a journal
\def\journal#1#2#3#4{\it #1\/ \bf #2 \rm (#3) \/ #4}

% 1=editors 2=title 3=publisher 4=year 5=pages      if in a collection
\def\collection#1#2#3#4#5{\rm in
     \bookfont #2 \rm (#1), #3, #4, pages #5}

\reference{\Bach} {Bach, G\"{u}nter}
{\"{U}ber eine Verallgemeinerung der Differenzengleichung der Stirlingschen
Zahlen $2$ Art und Einige damit zusammenhngende Fragen}
\journal {J. Reine Angew. Math.} 
{233} {1968} {213--220}.

\reference{\Canfield} {Canfield, E. R.}
{Location of the maximum Stirling number(s) of the second kind}
\journal {Studies in Appl. Math.}{59}{1978}{83--93}.

\book{\Comtet} {Comtet, Louis}
{Advanced Combinatorics; The art of finite and infinite
expansions} {Reidel, Boston} {1974}.
 
\reference{\Dobson} {Dobson, A. J.}
{A note on Stirling numbers of the second kind}
\journal {J. Combinatorial Theory} {5} {1968} {212--214}.

\reference{\Erdos} {Erd\H{o}s, Paul}
{On a conjecture of Hammersley}
\journal {Journal of the London Mathematical Society} 
{28} {1953} {232--236}.

\reference {\Harborth} {Harborth, Heiko}
{\"{U}ber das Maximum bei Stirlingschen Zahlen $2$. Art}
\journal {J. Reine Angew. Math.} {230} {1968} {213--214}.

\reference {\Harper} {Harper, L. H.}
{Stirling behavior is asymptotically normal}
\journal {Ann. Math. Stat.} {31} {1967} {410--414}.

\reference{\Hayman} {Hayman, Walter K.}
{A generalisation of Stirling's formula}
\journal{Journal f\"{u}r die reine und angewandte Mathematik}
{196} {1956} {67--95}.
 
\reference {\Huxley} {Huxley, M. N.}
{The integer points close to a curve, III}
\collection {K. Gy\H{o}ry, H. Iwaniec, and J. Urbanowicz, editors}
            {Number Theory in Progress} 
            {Walter de Gruyter, Berlin}
            {1999}
            {911--940}.
 
\reference {\KanoldA} {Kanold, Hans-Joachim}
{\"{U}ber Stirlingsche Zahlen $2$. Art}
\journal {J. Reine Angew. Math.} {229} {1968} {188--193}.

\reference {\KanoldB} {Kanold, Hans-Joachim}
{\"{U}ber eine asymptotische Absch\"{a}tzung bei Stirlingschen Zahlen $2$. Art}
\journal {J. Reine Angew. Math.} {230} {1968} {211--212}.

\reference {\KanoldC} {Kanold, Hans-Joachim}
{Einige neuere Abschtzungen bei
Stirlingschen Zahlen $2$. Art}
\journal {J. Reine Angew. Math.} {238} {1969} {148--160}.

\reference {\Lieb} {Lieb, E. H.}
{Concavity properties and a generating function for Stirling numbers}
\journal {J. Combinatorial Theory} {5} {1968} {203--206}.

\reference {\Menon} {Menon, V. V.}
{On the maximum of Stirling numbers of the second kind}
\journal {J. Combinatorial Theory, A} {15} {1973} {11--24}.

\reference {\Moser} {Moser, L. and M. Wyman}
{Stirling numbers of the second kind}
\journal {Duke Math. J.} {25} {1957} {29--43}.

\reference {\Mullin} {Mullin, R.}
{On Rota's problem concerning partitions}
\journal {Aequationes Mathematicae} {2} {1969} {98--104}.

\reference {\Odlyzko} {Odlyzko, Andrew}
{Asymptotic enumeration methods}
\collection {R. L. Graham, M. Gr\"{o}tschel, L. Lov\'{a}sz, editors}
{Handbook of Combinatorics, volume II}
{The MIT Press, North-Holland}
{1995}
{1063--1229}.

\reference{\RD} {Rennie, B. C., and A. J. Dobson}
{On Stirling numbers of the second kind}
\journal {J. Combinatorial Theory} {7} {1969} {116--121}.

%%%%%%%%%%%%%%%%%%\vfill\eject

\reference{\Wegner} {Wegner, Horst}
{\"{U}ber das Maximum bei Stirlingschen Zahlen zweiter Art}
\journal {J. Reine Angew. Math.} {262/263} {1973} {134--143}.

\book{\Wilf} {Wilf, Herbert S.}
{Generatingfunctionology}
{Academic Press, San Diego} {1990}.

\bye
